export P=sip-qt5
export V=4.19.14
export B=1
export MAINTAINER=JuergenFischer

export PYTHON=Python37

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f sip-$V.tar.gz ] || wget https://www.riverbankcomputing.com/static/Downloads/sip/sip-$V.tar.gz
[ -f ../configure.py ] || tar -C .. -xzf sip-$V.tar.gz --xform s,^sip-$V,.,

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in x86 x86_64; do
	case "$ARCH" in
	x86)
		export OSGEO4W_ROOT=/c/OSGeo4W
		export VCARCH=x86
		;;

	x86_64)
		export OSGEO4W_ROOT=/c/OSGeo4W64
		export VCARCH=amd64
		;;

	*)
        	echo invalid arch
        	exit 1
		;;

	esac

	export R=$OSGEO4W_REP/$ARCH/release/python3/$P
	mkdir -p $R/$P

	cat <<EOF >$R/setup.hint
sdesc: "Python3/C++ bindings generator (Development)"
ldesc: "Python3/C++ bindings generator (Development)"
category: Libs 
maintainer: $MAINTAINER
requires: python3-core
EOF

	cp ../LICENSE-GPL2 $R/$P/$P.txt

	export INSTDIR=install-$ARCH

	fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
	fetchenv "$OSGEO4W_ROOT/bin/py3_env.bat"
	fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
	export PATH=$PATH:/bin

	cd ..
	export DSTDIR=$PWD/osgeo4w/$INSTDIR
	rm -rf $DSTDIR
	mkdir -p $DSTDIR/apps/$PYTHON/lib/site-packages $DSTDIR/apps/$PYTHON/Scripts $DSTDIR/apps/$PYTHON/include

	python configure.py \
		--destdir "$(cygpath -w $DSTDIR/apps/$PYTHON/lib/site-packages)" \
		--bindir "$(cygpath -w $DSTDIR/apps/$PYTHON/Scripts)" \
		--incdir "$(cygpath -w $DSTDIR/apps/$PYTHON/include)"

	nmake clean
	nmake
	nmake install

	cd osgeo4w
	mkdir -p $INSTDIR/etc/postinstall $INSTDIR/etc/preremove

	cat <<EOF >$INSTDIR/etc/postinstall/$P.bat
set OSGEO4W_ROOT=%OSGEO4W_ROOT:\\=\\\\%
textreplace -std -t apps\\$PYTHON\\Lib\\site-packages\\sipconfig.py
EOF

	cat <<EOF >$INSTDIR/etc/preremove/$P.bat
del apps\\$PYTHON\\Lib\\site-packages\\sipconfig.py
EOF

	sed \
		-e "s/$(cygpath -w $OSGEO4W_ROOT | sed -e 's/\\/\\\\\\\\/g')/@osgeo4w@/g" \
		-e "s/$(cygpath -w $DSTDIR | sed -e 's/\\/\\\\\\\\/g')/@osgeo4w@/g" \
		$INSTDIR/apps/$PYTHON/Lib/site-packages/sipconfig.py \
		>$INSTDIR/apps/$PYTHON/Lib/site-packages/sipconfig.py.tmpl
	rm $INSTDIR/apps/$PYTHON/Lib/site-packages/sipconfig.py

	cp ../LICENSE $R/$P-$V-$B.txt

	/usr/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 apps etc
	/usr/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh
done

date
